==> haskell-aeson-better-errors-0.9.1.3-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-fFMd1CEz5gIoly2g5wVcd
key:                  aeson-better-errors-0.9.1.3-fFMd1CEz5gIoly2g5wVcd
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  63b8b418238c1a06e790e52318259233
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-fFMd1CEz5gIoly2g5wVcd
depends:
    aeson-2.1.2.1-30WJrKK1Pbc1pP0H7Lz8HG base-4.17.2.1
    bytestring-0.11.5.3 dlist-1.0-E99MqJW5mmB4kr4PCgIESI mtl-2.2.2
    scientific-0.3.8.0-Ksazu1q4lbv7nBtRDhz1zC text-2.0.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-JDDg5JU7nYP5ffg7vR2UZh
    vector-0.13.2.0-LerqRcvS8LMBGXOi8GqDsa
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.3-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-better-errors
version:              0.9.1.3
visibility:           public
id:                   aeson-better-errors-0.9.1.3-KGxWijHwHoX5LHcy9zBbQG
key:                  aeson-better-errors-0.9.1.3-KGxWijHwHoX5LHcy9zBbQG
license:              MIT
maintainer:           harry@garrood.me
author:               Harry Garrood
homepage:             https://github.com/hdgarrood/aeson-better-errors
synopsis:             Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.

category:             Text, Web, JSON
abi:                  ba0247785521b9511c16f202483f5492
exposed:              True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal

hidden-modules:       Data.Aeson.BetterErrors.Utils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-better-errors-0.9.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-better-errors
hs-libraries:         HSaeson-better-errors-0.9.1.3-KGxWijHwHoX5LHcy9zBbQG
depends:
    aeson-2.1.2.1-4RB85zdNr5p3whZ1np3a31 base-4.17.2.1
    bytestring-0.11.5.3 dlist-1.0-E99MqJW5mmB4kr4PCgIESI mtl-2.2.2
    scientific-0.3.8.0-75VbuY3tmfA8QFAgCCeEHk text-2.0.2
    transformers-0.5.6.2
    transformers-compat-0.7.2-F1TSDgHxVH372cWL2D3XnQ
    unordered-containers-0.2.20-L410VxfvorQ5RMb8wocThG
    vector-0.13.2.0-B3Rnif6nhJNLHPAZlzHp2g
    void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:
    /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock

haddock-html:         /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
